==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/FlowModAddMatchFromFieldCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.field._case.FlowModAddMatchFromField;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case flow-mod-add-match-from-field-case {
 *   container flow-mod-add-match-from-field {
 *     leaf flow-mod-num-bits {
 *       type uint16;
 *     }
 *     leaf src-field {
 *       type uint32;
 *     }
 *     leaf src-ofs {
 *       type uint16;
 *     }
 *     leaf dst-field {
 *       type uint32;
 *     }
 *     leaf dst-ofs {
 *       type uint16;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-add-match-from-field-case</i>
 *
 */
public interface FlowModAddMatchFromFieldCase
    extends
    DataObject,
    Augmentable<FlowModAddMatchFromFieldCase>,
    FlowModSpec
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-add-match-from-field-case");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.field._case.FlowModAddMatchFromField</code> <code>flowModAddMatchFromField</code>, or <code>null</code> if not present
     */
    @Nullable FlowModAddMatchFromField getFlowModAddMatchFromField();

}

==> openflowplugin-extension-nicira-0.9.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/FlowModAddMatchFromFieldCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.field._case.FlowModAddMatchFromField;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case flow-mod-add-match-from-field-case {
 *   container flow-mod-add-match-from-field {
 *     leaf flow-mod-num-bits {
 *       type uint16;
 *     }
 *     leaf src-field {
 *       type uint32;
 *     }
 *     leaf src-ofs {
 *       type uint16;
 *     }
 *     leaf dst-field {
 *       type uint32;
 *     }
 *     leaf dst-ofs {
 *       type uint16;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-add-match-from-field-case</i>
 *
 */
public interface FlowModAddMatchFromFieldCase
    extends
    DataObject,
    Augmentable<FlowModAddMatchFromFieldCase>,
    FlowModSpec
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-add-match-from-field-case");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.FlowModAddMatchFromFieldCase> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.FlowModAddMatchFromFieldCase.class;
    }
    
    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.field._case.FlowModAddMatchFromField</code> <code>flowModAddMatchFromField</code>, or <code>null</code> if not present
     */
    @Nullable FlowModAddMatchFromField getFlowModAddMatchFromField();

}
